@@ -11,7 +11,7 @@ def get_icon(fielddef, state=None):
         return "mdi:timer"
     elif isinstance(type_, types.EnumType):
         if tuple(sorted(type_.values)) in [("off", "on"), ("no", "yes")]:
-            if state is False:
+            if state in (False, "off", "no"):
                 return "mdi:toggle-switch-off"
             else:
                 return "mdi:toggle-switch"
