@@ -1,11 +1,8 @@
 """Message Defintions."""
 import collections
-import copy
 import re
 from fnmatch import fnmatchcase
 
-from .msgdef import MsgDef
-
 
 class MsgDefs:
 
@@ -99,15 +96,7 @@ class MsgDefs:
                         prio = msgdef.prio
                     else:
                         prio = int(prio)
-                    yield MsgDef(
-                        msgdef.circuit,
-                        msgdef.name,
-                        tuple(copy.copy(fielddef) for fielddef in fields),
-                        read=msgdef.read,
-                        prio=prio,
-                        write=msgdef.write,
-                        update=msgdef.update,
-                    )
+                    yield msgdef.replace(children=fields, prio=prio)
         else:
             raise ValueError(f"Invalid pattern {pattern!r}")
 
