@@ -770,16 +770,24 @@ class DateTimeType(Type):
 class WeekdayType(Type):
     """Weekday Type."""
 
-    # def decode(self, value):
-    #     raise ValueError("TODO")
+    def decode(self, value):
+        """Decode `value`."""
+        return value
+    def encode(self, value):
+        """Encode `value`."""
+        return value
 
 
 class PinType(Type):
 
     """Pin."""
 
-    # def decode(self, value):
-    #     return value
+    def decode(self, value):
+        """Decode `value`."""
+        return value
+    def encode(self, value):
+        """Encode `value`."""
+        return value
 
 
 TYPEMAP = {
